@@ -53,11 +53,6 @@ serve_it = function(
     owd = setwd(site_root(config)); on.exit(setwd(owd), add = TRUE)
 
     if (!getOption('blogdown.generator.server', FALSE)) {
-      if (is_windows() && getOption('servr.daemon', FALSE)) {
-        if (!xfun::loadable('later')) stop(
-          "Please install the 'later' package: install.packages('later')", call. = FALSE
-        )
-      }
       build_site(TRUE)
       n = nchar(pdir)
       return(servr::httw(site.dir = pdir, baseurl = baseurl, handler = function(...) {
@@ -71,9 +66,6 @@ serve_it = function(
       }, dir = '.', ...))
     }
 
-    if (!xfun::loadable('processx') || !xfun::loadable('later')) stop(
-      "Please install the packages 'processx' and 'later'", call. = FALSE
-    )
     server = servr::server_config(...)
 
     # launch the hugo/jekyll/hexo server
